#
# spec file for package nginx-ingress-controller
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global import_path k8s.io/ingress-nginx

Name:           nginx-ingress-controller
Version:        0.15.0
Release:        lp152.3.4
Summary:        Kubernetes ingress controller for nginx
License:        Apache-2.0
Group:          Productivity/Networking/Web/Proxy
Url:            https://github.com/kubernetes/ingress-nginx
Source0:        https://github.com/kubernetes/ingress-nginx/archive/nginx-%{version}.tar.gz#/ingress-nginx-%{version}.tar.gz
Source1:        nginx-ingress-controller-rpmlintrc
Patch0:         rootless-is-port-available.patch
Requires(pre):  %fillup_prereq
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.10

%description
An Ingress controller is meant to handle all the quirks associated
with a specific "class" of Ingress.

An Ingress Controller is a daemon, deployed as a Kubernetes Pod, that watches
the apiserver's /ingresses endpoint for updates to the Ingress resource. Its
job is to satisfy requests for Ingresses.

%package -n kubernetes-404-server
Summary:        Webserver needed for the Kubernetes ingress functionality
Group:          Productivity/Networking/Web/Proxy

%description -n kubernetes-404-server
404-server is a webserver that satisfies the Kubernetes ingress, which
means it has to do two things:

* Serve a 404 page at /
* Serve 200 on a /healthz

%prep
%setup -q -n ingress-nginx-nginx-%{version}
%patch0 -p1

%build
%goprep %{import_path}
export GOPATH=${RPM_BUILD_DIR}/go
CGO_ENABLED=0 go build -a -installsuffix cgo -o nginx-ingress-controller k8s.io/ingress-nginx/cmd/nginx
CGO_ENABLED=0 go build -a -installsuffix cgo -o kubernetes-404-server k8s.io/ingress-nginx/images/404-server

%install
install -D -m 0755 nginx-ingress-controller %{buildroot}%{_bindir}/nginx-ingress-controller
install -D -m 0755 kubernetes-404-server %{buildroot}%{_bindir}/kubernetes-404-server

%files
%{_bindir}/nginx-ingress-controller
%license LICENSE

%files -n kubernetes-404-server
%{_bindir}/kubernetes-404-server

%changelog
* Wed Dec 12 2018 Michał Rostecki <mrostecki@suse.de>
- Update Go to 1.10.
* Thu Oct  4 2018 Michał Rostecki <mrostecki@suse.de>
- Require at least 1.9 version of Go (newer versions can be used)
- Use https instead of http in links
* Tue Oct  2 2018 fcastelli@suse.com
- Cleanup of the spec file:
  * Unpack source code using RPM macros. This makes easier to apply
    patches
  * Use go packaging macros to setup the build environment
  * Get rid of the Go 1.9 requirment, even 1.11 is working fine
- Add 'rootless-is-port-available.patch': this is a backport of a fix
  that allows the controller to run as non-root user. bsc#1107700
* Thu Aug 16 2018 mrostecki@suse.de
- Downgrade Go to 1.9
  * nginx-ingress-controller builds perfectly on 1.9, which is the
    newest version supported on SLE12 and SLE15
* Sat Jul 28 2018 jengelh@inai.de
- Fix the silly backslash escapes in the description.
- Trim non-telling part of the description.
* Mon Jun 25 2018 mrostecki@suse.com
- Change tarball name from nginx-%%{version}.tar.gz to
  ingress-nginx-%%{version}.tar.gz
* Tue Jun 19 2018 mrostecki@suse.com
- Update to 0.15.0
  * TLS tests
  * improve build-dev-env.sh script
  * always use x-request-id
  * Add basic security context to deployment YAMLs
  * Add google analytics [ci skip]
  * Assert or install go-bindata before incanting
  * Refactor Lua balancer
  * Change TrimLeft for TrimPrefix on the from-to-www redirect
  * add resty cookie
  * [ci skip] bump nginx baseimage version
  * Refactor update of status removing initial check for
    loadbalancer
  * Update go version in fortune teller image
  * force backend sync when worker starts
  * Remove warning when secret is used only for authentication
  * Fix and simplify local dev workflow and execution of e2e tests
* Tue Jun 19 2018 mrostecki@suse.com
- Define kubernetes-404-server and nginx-ingress-controller
  packages in the same spec
* Fri Jun  8 2018 dcassany@suse.com
- Make use of %%license macro
* Mon Mar 19 2018 mrostecki@suse.com
- Initial release
